pub struct TelemetryLayer {
pub inner_layer: Layer<Registry, DefaultFields, TelemetryFormatter, NonBlocking>,
}Expand description
A tracing Layer to generate telemetry to be later consumed into InfluxDB
This tracing Layer formats telemetry and stores the output in a known
location ($FUEL_HOME/tmp/
Fields
inner_layer: Layer<Registry, DefaultFields, TelemetryFormatter, NonBlocking>Implementations
Sourceimpl TelemetryLayer
impl TelemetryLayer
Sourcepub fn __new() -> Result<(Self, WorkerGuard)>
pub fn __new() -> Result<(Self, WorkerGuard)>
Although public, __new() is only intended to be called via the
following constructor macros:
fuel_telemetry::new!()fuel_telemetry::new_with_watchers!()fuel_telemetry::new_with_watchers_and_init!()